def to_bytes(arg):
    """Convert `arg` to bytes.

    The latin-1 codec was used here when the package gained Python 3 support in
    2015. It's not clear why UTF-8 was not chosen instead. Since passwords
    generated by this code have been persisted in many user folders it is not
    possible to change the encoding. A UTF-8 fallback is used for password
    characters that are not part of the latin-1 set of characters.
    """
    if isinstance(arg, str):
        try:
            arg = arg.encode('latin-1')
        except UnicodeEncodeError:
            arg = arg.encode('UTF-8')
    return arg


def to_string(arg):
    """Convert `arg` to text."""
    if isinstance(arg, bytes):
        arg = arg.decode('ascii', 'replace')
    return arg
